package org.apidesign.apifest08.currency;

import java.math.BigDecimal;


public class ConvertorFactory {

    public static Convertor getConvertor(CurrencyType from, CurrencyType to) {
        if (from == CurrencyType.CZK && to == CurrencyType.USD) {
             return new BasicConvertor(new BigDecimal(17));
        } else if (from == CurrencyType.SKK && to == CurrencyType.CZK) {
            double rate = 0.8d;
            return new BasicConvertor(new BigDecimal(rate));
        }


        throw new UnsupportedOperationException("Conversion not supported now");
    }

    private static class BasicConvertor implements Convertor {

        private final BigDecimal conversionRate;

        BasicConvertor(BigDecimal conversionRate) {
            this.conversionRate = conversionRate;
        }

        @Override
        public long convertTo(long amount) {
            return (long) (conversionRate.doubleValue() * amount);
        }

        @Override
        public long convertFrom(long amount) {
            return (long) (amount / conversionRate.doubleValue());
        }
    }
}
