
package org.apidesign.apifest08.currency;

import java.math.BigDecimal;
import java.util.Date;

/**
 * Exchange rate provider - can provide fixed exchange rate which does not depend
 * on date (method {@link #getExchangeRate()} ) or exchange rate based on date (method {@link #getExchangeRate(java.util.Date) }).
 * 
 * 
 * @author arnostvalicek
 */
public class ExchangeRateProvider {
    BigDecimal fromValue, toValue;
    ConvertorCurrency fromCurrency, toCurrency;

    /**
     * Simple constructor for <code>ExchangeRateProviderM</code> which can provide fixed exchange rate.
     * 
     * Describes conversion <em>from</em> to <em>to</em> currency.
     * 
     * @param fromValue From value. BigDecimal value, precision should be set to currency precision.
     * @param fromCurrency From currency.
     * @param toValue To value. BigDecimal value, precision should be set to currency precision.
     * @param toCurrency To currency.
     */
    public ExchangeRateProvider(BigDecimal fromValue, ConvertorCurrency fromCurrency, BigDecimal toValue, ConvertorCurrency toCurrency) {
        this.fromValue = fromValue;
        this.toValue = toValue;
        this.fromCurrency = fromCurrency;
        this.toCurrency = toCurrency;
    }
    
    /**
     * Get fixed exange rate for currencies (from->to).
     * @return Returns exchange rate.
     */
    public ExchangeRate getExchangeRate() {
        return new ExchangeRate(fromValue, toValue);
    }
    
    /**
     * Get exchange rate for currencies (from->to) based on provided date.
     * @param date Date for which exchange rate should be provided.
     * @return Returns exchange rate 
     */
    public ExchangeRate getExchangeRate(Date date) {
        return new ExchangeRate(fromValue, toValue);
    }
    

    ConvertorCurrency getFromCurrency() {
        return fromCurrency;
    }
    
    ConvertorCurrency getToCurrency() {
        return toCurrency;
    }
    

}
